==> order-center-domain-3.1.0-CLOUD-DEV-20231102.095705-143-sources.jar: com/tydic/dyc/oc/service/domainservice/UocChngOrderConfirmOrRefuseForInspServiceImpl.java <==
package com.tydic.dyc.oc.service.domainservice;

import com.tydic.dyc.oc.components.thread.UocThreadPool;
import com.tydic.dyc.oc.components.thread.runnable.UocSyncEsRunnable;
import com.tydic.dyc.oc.components.thread.runnable.bo.SyncEsRunnableBo;
import com.tydic.dyc.oc.transactionservice.UocChngOrderConfirmOrRefuseForInspTransaction;
import com.tydic.dyc.oc.config.UocIndexConfig;
import com.tydic.dyc.oc.constants.UocConstant;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.service.domainservice.bo.*;
import lombok.extern.ohaotian.HTServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.*;

/**
 * @Author WangJiuXin
 * @date 2023/6/20
 * @decr  新变更确认/拒绝（验收单维度）服务实现
 **/
@HTServiceImpl
public class UocChngOrderConfirmOrRefuseForInspServiceImpl implements UocChngOrderConfirmOrRefuseForInspService{

    @Autowired
    private UocChngOrderConfirmOrRefuseForInspTransaction uocChngOrderConfirmOrRefuseForInspTransaction;
    @Autowired
    private UocThreadPool uocThreadPool;
    @Autowired
    private UocIndexConfig uocIndexConfig;


    @Override
    public UocChngOrderConfirmOrRefuseForInspRspBo dealConfirmOrRefuse(UocChngOrderConfirmOrRefuseForInspReqBo reqBo) {
        UocChngOrderConfirmOrRefuseForInspRspBo rspBo = uocChngOrderConfirmOrRefuseForInspTransaction.dealConfirmOrRefuse(reqBo);

        if (UocRspConstants.RSP_CODE_SUCCESS.equals(rspBo.getRespCode())) {
            //本地线程同步es
            syncEs(reqBo, rspBo);
        }

        return rspBo;

    }

    private void syncEs(UocChngOrderConfirmOrRefuseForInspReqBo reqBo, UocChngOrderConfirmOrRefuseForInspRspBo rspBo) {
        List<SyncEsRunnableBo> list = new ArrayList<>();
        //同步变更单
        for (UocChngOrderConfirmOrRefuseReqItemBo uocChngOrderConfirmOrRefuseReqItemBo : reqBo.getChngOrderList()) {
            SyncEsRunnableBo chngBo = new SyncEsRunnableBo();
            chngBo.setIndexName(uocIndexConfig.getChngOrderIndex());
            chngBo.setOrderId(uocChngOrderConfirmOrRefuseReqItemBo.getOrderId());
            chngBo.setObjId(uocChngOrderConfirmOrRefuseReqItemBo.getChngOrderId());
            chngBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(chngBo);
        }

        //同步销售单
        List<String> saleOrderIdList = rspBo.getSaleOrderIdList();
        for (String saleOrderId : saleOrderIdList) {
            String[] split = saleOrderId.split("-");
            SyncEsRunnableBo saleOrderBo = new SyncEsRunnableBo();
            saleOrderBo.setIndexName(uocIndexConfig.getSaleOrderIndex());
            saleOrderBo.setOrderId(Long.valueOf(split[1]));
            saleOrderBo.setObjId(Long.valueOf(split[0]));
            saleOrderBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(saleOrderBo);
        }

        //同步验收单
        List<String> inspOrderIdList = rspBo.getInspOrderIdList();
        for (String inspOrderId : inspOrderIdList) {
            String[] split = inspOrderId.split("-");
            SyncEsRunnableBo saleOrderBo = new SyncEsRunnableBo();
            saleOrderBo.setIndexName(uocIndexConfig.getInspOrderIndex());
            saleOrderBo.setOrderId(Long.valueOf(split[1]));
            saleOrderBo.setObjId(Long.valueOf(split[0]));
            saleOrderBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(saleOrderBo);
        }

        uocThreadPool.executeRunnable(new UocSyncEsRunnable(list));
    }


}

==> order-center-domain-3.2.2-CLOUD-DEV-20240506.091628-6-sources.jar: com/tydic/dyc/oc/service/domainservice/UocChngOrderConfirmOrRefuseForInspServiceImpl.java <==
package com.tydic.dyc.oc.service.domainservice;

import com.tydic.dyc.oc.components.thread.UocThreadPool;
import com.tydic.dyc.oc.components.thread.runnable.UocSyncEsRunnable;
import com.tydic.dyc.oc.components.thread.runnable.bo.SyncEsRunnableBo;
import com.tydic.dyc.oc.transactionservice.UocChngOrderConfirmOrRefuseForInspTransaction;
import com.tydic.dyc.oc.config.UocIndexConfig;
import com.tydic.dyc.oc.constants.UocConstant;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.service.domainservice.bo.*;
import lombok.extern.ohaotian.HTServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.*;

/**
 * @Author WangJiuXin
 * @date 2023/6/20
 * @decr  新变更确认/拒绝（验收单维度）服务实现
 **/
@HTServiceImpl
public class UocChngOrderConfirmOrRefuseForInspServiceImpl implements UocChngOrderConfirmOrRefuseForInspService{

    @Autowired
    private UocChngOrderConfirmOrRefuseForInspTransaction uocChngOrderConfirmOrRefuseForInspTransaction;
    @Autowired
    private UocThreadPool uocThreadPool;
    @Autowired
    private UocIndexConfig uocIndexConfig;


    @Override
    public UocChngOrderConfirmOrRefuseForInspRspBo dealConfirmOrRefuse(UocChngOrderConfirmOrRefuseForInspReqBo reqBo) {
        UocChngOrderConfirmOrRefuseForInspRspBo rspBo = uocChngOrderConfirmOrRefuseForInspTransaction.dealConfirmOrRefuse(reqBo);

        if (UocRspConstants.RSP_CODE_SUCCESS.equals(rspBo.getRespCode())) {
            //本地线程同步es
            syncEs(reqBo, rspBo);
        }

        return rspBo;

    }

    private void syncEs(UocChngOrderConfirmOrRefuseForInspReqBo reqBo, UocChngOrderConfirmOrRefuseForInspRspBo rspBo) {
        List<SyncEsRunnableBo> list = new ArrayList<>();
        //同步变更单
        for (UocChngOrderConfirmOrRefuseReqItemBo uocChngOrderConfirmOrRefuseReqItemBo : reqBo.getChngOrderList()) {
            SyncEsRunnableBo chngBo = new SyncEsRunnableBo();
            chngBo.setIndexName(uocIndexConfig.getChngOrderIndex());
            chngBo.setOrderId(uocChngOrderConfirmOrRefuseReqItemBo.getOrderId());
            chngBo.setObjId(uocChngOrderConfirmOrRefuseReqItemBo.getChngOrderId());
            chngBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(chngBo);
        }

        //同步销售单
        List<String> saleOrderIdList = rspBo.getSaleOrderIdList();
        for (String saleOrderId : saleOrderIdList) {
            String[] split = saleOrderId.split("-");
            SyncEsRunnableBo saleOrderBo = new SyncEsRunnableBo();
            saleOrderBo.setIndexName(uocIndexConfig.getSaleOrderIndex());
            saleOrderBo.setOrderId(Long.valueOf(split[1]));
            saleOrderBo.setObjId(Long.valueOf(split[0]));
            saleOrderBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(saleOrderBo);
        }

        //同步验收单
        List<String> inspOrderIdList = rspBo.getInspOrderIdList();
        for (String inspOrderId : inspOrderIdList) {
            String[] split = inspOrderId.split("-");
            SyncEsRunnableBo saleOrderBo = new SyncEsRunnableBo();
            saleOrderBo.setIndexName(uocIndexConfig.getInspOrderIndex());
            saleOrderBo.setOrderId(Long.valueOf(split[1]));
            saleOrderBo.setObjId(Long.valueOf(split[0]));
            saleOrderBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(saleOrderBo);
        }

        //同步发货单
        List<String> shipOrderIdList = rspBo.getShipOrderIdList();
        for (String shipOrderId : shipOrderIdList) {
            String[] split = shipOrderId.split("-");
            SyncEsRunnableBo saleOrderBo = new SyncEsRunnableBo();
            saleOrderBo.setIndexName(uocIndexConfig.getShipOrderIndex());
            saleOrderBo.setOrderId(Long.valueOf(split[1]));
            saleOrderBo.setObjId(Long.valueOf(split[0]));
            saleOrderBo.setOpFlag(UocConstant.ES_SYNC_OP_FLAG.SAVE);
            list.add(saleOrderBo);
        }

        uocThreadPool.executeRunnable(new UocSyncEsRunnable(list));
    }


}
